==> xlniuxdata-vipgame-1.0.65-20160728.021948-22-sources.jar: com/xunlei/niux/data/vipgame/dao/games/CpsGamesDaoImpl.java <==
package com.xunlei.niux.data.vipgame.dao.games;

import com.ferret.common.dao.BaseDaoImpl;
import com.xunlei.niux.data.vipgame.util.ObjectMapper;
import com.xunlei.niux.data.vipgame.vo.CpsGames;
import org.apache.commons.lang.StringUtils;

import java.util.List;

/**
 * Created by lizeyu on 2016/7/21.
 */
public class CpsGamesDaoImpl  extends BaseDaoImpl implements CpsGamesDao{


    @Override
    public int countUsingLike(CpsGames query){
        StringBuilder sql = new StringBuilder("select count(*) from cpsgames where 1=1 ");

        if(StringUtils.isNotEmpty(query.getGameId())){
            sql.append(" and gameId = '" + query.getGameId() + "'");
        }

        if(StringUtils.isNotEmpty(query.getGameNo())){
            sql.append(" and gameNo = '" + query.getGameNo() +  "'");
        }

        if(StringUtils.isNotEmpty(query.getGameName())){
            sql.append(" and gameName like '%" + query.getGameName() + "%'");
        }

        if(null != query.getStatus()){
            sql.append(" and status = " + query.getStatus());
        }

        if(null != query.getSourceType()){
            sql.append(" and sourceType = " + query.getSourceType());
        }

        if(StringUtils.isNotEmpty(query.getSimpleName())){
            sql.append(" and simpleName = '" + query.getSimpleName() +  "'");
        }

        return getJdbcTemplate().queryForInt(sql.toString());
    }

    @Override
    public List<CpsGames> queryCpsGamesList(CpsGames query){
        StringBuilder sql = new StringBuilder("select * from cpsgames where 1=1 ");

        if(StringUtils.isNotEmpty(query.getGameId())){
            sql.append(" and gameId = '" + query.getGameId() + "'");
        }

        if(StringUtils.isNotEmpty(query.getGameNo())){
            sql.append(" and gameNo = '" + query.getGameNo() +  "'");
        }

        if(StringUtils.isNotEmpty(query.getGameName())){
            sql.append(" and gameName like '%" + query.getGameName() + "%'");
        }

        if(null != query.getStatus()){
            sql.append(" and status = " + query.getStatus());
        }

        if(null != query.getSourceType()){
            sql.append(" and sourceType = " + query.getSourceType());
        }

        if(StringUtils.isNotEmpty(query.getSimpleName())){
            sql.append(" and simpleName = '" + query.getSimpleName() +  "'");
        }

        return getJdbcTemplate().query( sql.toString(), new ObjectMapper(CpsGames.class));
    }
}

==> xlniuxdata-vipgame-1.0.65-20160728.080553-24-sources.jar: com/xunlei/niux/data/vipgame/dao/games/CpsGamesDaoImpl.java <==
package com.xunlei.niux.data.vipgame.dao.games;

import com.ferret.common.dao.BaseDaoImpl;
import com.ferret.common.dao.vo.Page;
import com.xunlei.niux.data.vipgame.util.ObjectMapper;
import com.xunlei.niux.data.vipgame.vo.CpsGames;
import org.apache.commons.lang.StringUtils;

import java.util.List;

/**
 * Created by lizeyu on 2016/7/21.
 */
public class CpsGamesDaoImpl  extends BaseDaoImpl implements CpsGamesDao{


    @Override
    public int countUsingLike(CpsGames query){
        StringBuilder sql = new StringBuilder("select count(*) from cpsgames where 1=1 ");

        if(StringUtils.isNotEmpty(query.getGameId())){
            sql.append(" and gameId = '" + query.getGameId() + "'");
        }

        if(StringUtils.isNotEmpty(query.getGameNo())){
            sql.append(" and gameNo = '" + query.getGameNo() +  "'");
        }

        if(StringUtils.isNotEmpty(query.getGameName())){
            sql.append(" and gameName like '%" + query.getGameName() + "%'");
        }

        if(null != query.getStatus()){
            sql.append(" and status = " + query.getStatus());
        }

        if(null != query.getSourceType()){
            sql.append(" and sourceType = " + query.getSourceType());
        }

        if(StringUtils.isNotEmpty(query.getSimpleName())){
            sql.append(" and simpleName = '" + query.getSimpleName() +  "'");
        }

        return getJdbcTemplate().queryForInt(sql.toString());
    }

    @Override
    public List<CpsGames> queryCpsGamesList(CpsGames query, Page page){
        StringBuilder sql = new StringBuilder("select * from cpsgames where 1=1 ");

        if(StringUtils.isNotEmpty(query.getGameId())){
            sql.append(" and gameId = '" + query.getGameId() + "'");
        }

        if(StringUtils.isNotEmpty(query.getGameNo())){
            sql.append(" and gameNo = '" + query.getGameNo() +  "'");
        }

        if(StringUtils.isNotEmpty(query.getGameName())){
            sql.append(" and gameName like '%" + query.getGameName() + "%'");
        }

        if(null != query.getStatus()){
            sql.append(" and status = " + query.getStatus());
        }

        if(null != query.getSourceType()){
            sql.append(" and sourceType = " + query.getSourceType());
        }

        if(StringUtils.isNotEmpty(query.getSimpleName())){
            sql.append(" and simpleName = '" + query.getSimpleName() +  "'");
        }

        int pageNo = page.getPageNo();
        int pageSize = page.getPageSize();
        sql.append(" order by 'inputTime' desc");
        sql.append(" limit " + ((pageNo - 1) * pageSize) + ", " + pageSize);

        return getJdbcTemplate().query( sql.toString(), new ObjectMapper(CpsGames.class));
    }
}
